database_jones_numfield: Table of number fields
===============================================

Description
-----------

This is a table of number fields with bounded ramification and degree
at most 6.

License
-------

GPLv2+


Upstream Contact
----------------

sage-devel@googlegroups.com

Dependencies
------------

None


Special Update/Build Instructions
---------------------------------

Created by taking the original old-style spkg and removing crud from it.
